package cn.com.qmth.examcloud.tool.utils;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.*;
import java.util.ArrayList;
import java.util.List;

public class FileUtils {

    private static Logger log = LoggerFactory.getLogger(FileUtils.class);

    private static final String encoding = "UTF-8";

    /**
     * 创建文件目录
     */
    public static boolean makeDirs(String dirPath) {
        if (StringUtils.isEmpty(dirPath)) {
            return false;
        }

        File folder = new File(dirPath);
        if (!folder.exists()) {
            return folder.mkdirs();
        }

        return true;
    }

    /**
     * 写入内容到文件（覆盖）
     */
    public static void writeFile(String filePath, String content) {
        File file = new File(filePath);
        FileUtils.makeDirs(file.getParent());

        try {
            if (!file.exists()) {
                file.createNewFile();
            }
        } catch (IOException e) {
            log.error(e.getMessage(), e);
            return;
        }

        if (content == null) {
            content = "";
        }

        try (FileOutputStream fos = new FileOutputStream(file);
             OutputStreamWriter osw = new OutputStreamWriter(fos, encoding);
             BufferedWriter bw = new BufferedWriter(osw);) {

            bw.write(content);
        } catch (IOException e) {
            log.error(e.getMessage(), e);
        }
    }

    /**
     * 写入内容到文件（追加）
     */
    public static void appendWriteFile(String filePath, String content) {
        if (content == null) {
            content = "";
        }

        try {
            File file = new File(filePath);
            org.apache.commons.io.FileUtils.writeStringToFile(file, content, encoding, true);
        } catch (IOException e) {
            log.error(e.getMessage(), e);
        }
    }

    /**
     * 读取文件内容
     */
    public static List<String> readFile(File file) {
        if (!file.exists() || !file.isFile()) {
            return new ArrayList<>();
        }

        List<String> lines = new ArrayList<>();
        try (FileInputStream fos = new FileInputStream(file);
             InputStreamReader isr = new InputStreamReader(fos, encoding);
             BufferedReader br = new BufferedReader(isr);) {

            String line;
            while ((line = br.readLine()) != null) {
                lines.add(line);
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }

        return lines;
    }

}